@@ -2,7 +2,7 @@
 # Licensed under the MIT License.
 
 from enum import Enum
-from typing import List
+from typing import Any, Dict, List, Tuple, Union
 
 
 class Dataset:
@@ -75,14 +75,48 @@ class CausalMetric:
     zstat: float
 
 
+class CausalPolicyGains:
+    recommended_policy_gains: float
+    treatment_gains: List[float]
+    treatments: List[str]
+
+
+class CausalPolicyTreeLeaf:
+    leaf: True
+    n_samples: int
+    treatment: str
+
+
+class CausalPolicyTreeInternal:
+    leaf: False
+    feature: str
+    threshold: Union[float, str]  # TODO: Categorical features
+    left: Union['CausalPolicyTreeInternal', CausalPolicyTreeLeaf]
+    right: Union['CausalPolicyTreeInternal', CausalPolicyTreeLeaf]
+
+
+class CausalPolicy:
+    treatment_feature: str
+    local_policies: List[Dict[str, Any]]
+    policy_gains: CausalPolicyGains
+    policy_tree: Union[CausalPolicyTreeInternal, CausalPolicyTreeLeaf]
+
+
 class CausalData:
-    globalCausalEffects: List[CausalMetric]
-    localCausalEffects: List[List[CausalMetric]]
+    global_effects: List[CausalMetric]
+    local_effects: List[List[CausalMetric]]
+    policies: List[CausalPolicy]
 
 
 class CounterfactualData:
-    cfsList: List[List[List[float]]]
-    featureNames: List[float]
+    cfs_list: List[List[List[float]]]
+    feature_names: List[str]
+    feature_names_including_target: List[str]
+    summary_importance: List[float]
+    local_importance: List[List[float]]
+    model_type: str
+    desired_class: str
+    desired_range: List[Tuple[float]]
 
 
 class ModelAnalysisData:
